@@ -36,11 +36,77 @@
 #include <QDBusReply>
 #include <QRegExpValidator>
 #include <QDebug>
+#include <QDateTime>
+#include <QLibrary>
 
 #include <netdb.h>
 
 static QString g_strModelFull;
 
+static bool isSdkInit = false;
+typedef bool (*pfInitialize)(const std::string&, bool);
+static pfInitialize InitializeSdk = nullptr;
+static pfWriteEventLog WriteEventLog = nullptr;
+const QString LibEventLog = "/usr/lib/libdeepin-event-log.so";
+static QLibrary *eventLib = nullptr;
+
+void loadEventlib()
+{
+    if (!isSdkInit) {
+        eventLib = new QLibrary(LibEventLog);
+        if (eventLib == nullptr) {
+            qInfo() << "no mem";
+            return;
+        }
+
+        eventLib->load();
+        if (!eventLib->isLoaded()) {
+            delete eventLib;
+            eventLib = nullptr;
+            qInfo() << "Load libdeepin-event-log.so failed!";
+            return;
+        }
+
+        InitializeSdk = (pfInitialize)(eventLib->resolve("Initialize"));
+        WriteEventLog = (pfWriteEventLog)eventLib->resolve("WriteEventLog");
+        if (InitializeSdk && InitializeSdk(APPNAME, true)) {
+            qInfo() << "sdk load success" ;
+            isSdkInit = true; // sdk初始化状态
+        }
+    }
+}
+
+bool isEventSdkInit()
+{
+    return isSdkInit;
+}
+
+void unloadEventLib()
+{
+    if (eventLib != nullptr && eventLib->isLoaded()) {
+        eventLib->unload();
+        eventLib = nullptr;
+    }
+
+    if (isSdkInit) {
+        isSdkInit = false;
+        InitializeSdk = nullptr;
+        WriteEventLog = nullptr;
+    }
+}
+
+pfWriteEventLog getWriteEventLog()
+{
+    return WriteEventLog;
+}
+
+QString getCurrentTime()
+{
+    QDateTime current_date_time = QDateTime::currentDateTime();
+    QString time = current_date_time.toString("yyyy-MM-dd hh:mm:ss");
+    return time;
+}
+
 QString getPrinterPPD(const char *name)
 {
     QString strPPD;
@@ -151,7 +217,7 @@ QString reslovedHost(const QString &strHost)
 
     struct hostent *host = gethostbyname(strHost.toUtf8().data());
     if (nullptr == host && HOST_NOT_FOUND == h_errno) {
-        return strHost + QObject::tr(" not found, please ask the administrator for help");
+        return QObject::tr("%1 not found, please ask the administrator for help, or enter the printer IP address in URI of Properties.").arg(strHost);
     }
 
     return QString();
