@@ -39,10 +39,15 @@
 #include <QProcess>
 #include <QDBusConnection>
 #include <QDBusPendingReply>
+#include <QJsonDocument>
+#include <QJsonObject>
+#include <QDateTime>
+#include <QFile>
 
 #include <algorithm>
 #include <regex>
 
+#include <pwd.h>
 DWIDGET_USE_NAMESPACE
 
 #define SUB_URI "/"
@@ -54,6 +59,97 @@ DCORE_USE_NAMESPACE
 
 static vector<string> g_subEvents = {"printer-deleted", "printer-added", "printer-state-changed", "job-progress", "job-state-changed"};
 
+static bool isLocalUserJob(int jobId)
+{
+    map<string, string> jobInfo;
+    QString jobOriginName;
+    if (g_jobManager->getJobById(jobInfo, jobId, 0) == 0) {
+        map<string, string>::const_iterator itjob;
+        for (itjob = jobInfo.begin(); itjob != jobInfo.end(); ++itjob) {
+            if (itjob->first == "job-originating-user-name") {
+                jobOriginName = attrValueToQString(itjob->second);
+                break;
+            }
+        }
+    }
+
+    struct passwd* pwd = getpwuid(getuid());
+    if (pwd != nullptr && (strcmp(jobOriginName.toStdString().c_str(), pwd->pw_name) != 0)) {
+        return false; // 如果打印任务名称与本地用户名不一致, 不处理通知
+    }
+    return true;
+}
+
+static QString getPrinterInfo(const QString &strName)
+{
+    QString strMakeAndModel;
+
+    try {
+        vector<string> requestAttrs;
+        requestAttrs.push_back("printer-make-and-model");
+        auto conPtr = CupsConnectionFactory::createConnectionBySettings();
+        if (!conPtr) {
+            return strMakeAndModel;
+        }
+        map<string, string> attrs = conPtr->getPrinterAttributes(strName.toStdString().c_str(), nullptr, &requestAttrs);
+
+        for (auto iter = attrs.begin(); iter != attrs.end(); ++iter) {
+            strMakeAndModel = QString::fromStdString(iter->second.data());
+            strMakeAndModel = strMakeAndModel.remove(0, 1);
+        }
+    } catch (const std::runtime_error &e) {
+        qWarning() << "Report execpt: " << QString::fromUtf8(e.what());
+        strMakeAndModel.clear();
+    }
+
+    return strMakeAndModel;
+}
+
+static QString getPpdInfo(const QString &strPpdName, const QString &info)
+{
+    QString strOut, strErr;
+    QString commond;
+    commond += "cat " + strPpdName;
+    if (shellCmd(commond, strOut, strErr) == 0) {
+        QStringList list = strOut.split("\n", QString::SkipEmptyParts);
+        int index = 0;
+        for (; index < list.size(); index++) {
+            if (list[index].contains(info))
+            break;
+        }
+        if (index == list.size()) {
+            return nullptr;
+        }
+
+        QStringList val = list[index].split(":", QString::SkipEmptyParts);
+        if (val.count() <= 1) {
+            return nullptr;
+        }
+        return val[1];
+    }
+
+    return nullptr;
+}
+
+static QString getPackageVerByName(const QString &packageName)
+{
+    QString strOut, strErr;
+    if (shellCmd(QString("dpkg -l %1").arg(packageName), strOut, strErr) == 0) {
+        QStringList list = strOut.split("\n", QString::SkipEmptyParts);
+        strOut = list.isEmpty() ? "" : list.last();
+        list = strOut.split(" ", QString::SkipEmptyParts);
+        return list.count() > 2 ? list[2] : QString();
+    }
+
+    return nullptr;
+}
+
+static QString formatDateTime(const QString &time)
+{
+    QDateTime timetemp = QDateTime::fromSecsSinceEpoch(static_cast<uint>(time.toInt()));
+    return timetemp.toString("yyyy-MM-dd hh:mm:ss");
+}
+
 CupsMonitor::CupsMonitor(QObject *parent)
     : QThread(parent)
     , m_jobId(0)
@@ -66,6 +162,7 @@ CupsMonitor::CupsMonitor(QObject *parent)
 CupsMonitor::~CupsMonitor()
 {
     stop();
+    unloadEventLib();
 }
 
 void CupsMonitor::initTranslations()
@@ -324,6 +421,15 @@ int CupsMonitor::getNotifications(int &notifysSize)
                 if (skip)
                     continue;
 
+                /* 过滤通知消息处理:
+                 * 1. 由于getNotifications没有origin name字段, jobid信息notify-job-id;
+                 * 2. 通过jobid获取job-originating-user-name字段
+                 * 3. job-originating-user-name与username不一致时, 结束通知处理
+                 */
+                if (!isLocalUserJob(iJob)) { // 非本地用户作业任务，不处理
+                    continue;
+                }
+
                 //通过判断同一个id，同一个状态插入的次数判断是否触发信号
                 if (insertJobMessage(iJob, iState, strReason)) {
                     qDebug() << "Emit job state changed signal" << iJob << iState << strReason;
@@ -362,6 +468,8 @@ int CupsMonitor::getNotifications(int &notifysSize)
                 }
                 case IPP_JOB_CANCELLED:
                     m_processingJob.remove(iJob);
+
+                    writeJobLog(iState == IPP_JSTATE_COMPLETED, iJob);
                     break;
                 default:
                     break;
@@ -427,6 +535,64 @@ int CupsMonitor::cancelSubscription()
     return 0;
 }
 
+void CupsMonitor::writeJobLog(bool isSuccess, int jobId)
+{
+    if (!isEventSdkInit()) {
+        loadEventlib();
+    }
+
+    QJsonObject obj;
+    obj.insert("status", isSuccess ? "Success" : "Abort");
+    QString strJobEndTime, strJobUri, strReason;
+    map<string, string> jobInfo;
+    if (g_jobManager->getJobById(jobInfo, jobId, 0) == 0) {
+        map<string, string>::const_iterator itjob;
+        for (itjob = jobInfo.begin(); itjob != jobInfo.end(); ++itjob) {
+            if (itjob->first == "time-at-completed") {
+                strJobEndTime = attrValueToQString(itjob->second);
+            } else if (itjob->first == "job-printer-uri") {
+                strJobUri = attrValueToQString(itjob->second);
+            }
+        }
+    }
+
+    strJobEndTime = formatDateTime(strJobEndTime);
+    obj.insert("jobEndTime", strJobEndTime);
+    obj.insert("printerInfo", strJobUri);
+
+    QString jobPrinterName = getPrinterNameFromUri(strJobUri);
+    QString  strFilePath = getPrinterPPD(jobPrinterName.toStdString().c_str());
+    QString pddPath = QFile::symLinkTarget(strFilePath);
+    QString driverInfo = getPrinterInfo(jobPrinterName);
+
+    obj.insert("printerName", jobPrinterName);
+    obj.insert("driverInfo", driverInfo);
+
+    QString driverType;
+    if (driverInfo.contains("Bisheng")) {
+        QString packageName = getPpdInfo(pddPath, "PackageName").replace(QRegExp("^ "), "").replace(QRegExp("\""), "");
+
+        // 获取包版本信息
+        QString ver = getPackageVerByName(packageName);
+        obj.insert("packageName", packageName);
+        obj.insert("packageVer", ver);
+        obj.insert("driverType", "bisheng");
+    } else {
+        obj.insert("driverType", "other");
+    }
+    obj.insert("version", getPackageVerByName(APPNAME));
+    obj.insert("tid", 1000100001); // 事件ID
+
+    QString logInfo = QString(QJsonDocument(obj).toJson(QJsonDocument::Compact));
+    qDebug() << "json data: " << logInfo;
+
+    pfWriteEventLog WriteEventLog = getWriteEventLog();
+    if (WriteEventLog) {
+        qDebug() << "job info";
+        WriteEventLog(logInfo.toStdString());
+    }
+}
+
 int CupsMonitor::initSubscription()
 {
     if (-1 != m_subId)
@@ -574,6 +740,10 @@ void CupsMonitor::spoolerEvent(QDBusMessage msg)
     if (!isRunning()) {
         if (args.size() == 3)
             m_jobId = args[1].toInt();
+
+        if (!isLocalUserJob(m_jobId)) {
+            return;
+        }
         start();
     }
 }
