@@ -1,32 +1,32 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1">
+<TS version="2.1" language="en">
 <context>
     <name>AddPrinterTask</name>
     <message>
-        <location filename="../../Common/vendor/addprinter.cpp" line="552"/>
+        <location filename="../../Common/vendor/addprinter.cpp" line="551"/>
         <source>URI and driver do not match.</source>
-        <translation type="unfinished"></translation>
+        <translation>URI and driver do not match.</translation>
     </message>
     <message>
-        <location filename="../../Common/vendor/addprinter.cpp" line="554"/>
+        <location filename="../../Common/vendor/addprinter.cpp" line="553"/>
         <source>Install hplip first and restart the app to install the driver again.</source>
-        <translation type="unfinished"></translation>
+        <translation>Install hplip first and restart the app to install the driver again.</translation>
     </message>
     <message>
-        <location filename="../../Common/vendor/addprinter.cpp" line="562"/>
+        <location filename="../../Common/vendor/addprinter.cpp" line="561"/>
         <source>Please select an hplip driver and try again.</source>
-        <translation type="unfinished"></translation>
+        <translation>Please select an hplip driver and try again.</translation>
     </message>
     <message>
-        <location filename="../../Common/vendor/addprinter.cpp" line="575"/>
+        <location filename="../../Common/vendor/addprinter.cpp" line="574"/>
         <source>URI can&apos;t be empty</source>
-        <translation type="unfinished"></translation>
+        <translation>URI can&apos;t be empty</translation>
     </message>
     <message>
-        <location filename="../../Common/vendor/addprinter.cpp" line="582"/>
+        <location filename="../../Common/vendor/addprinter.cpp" line="581"/>
         <source> not found</source>
-        <translation type="unfinished"></translation>
+        <translation> not found</translation>
     </message>
 </context>
 <context>
@@ -34,37 +34,37 @@
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="305"/>
         <source>Check printer settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Check printer settings</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="314"/>
         <source>Checking printer settings...</source>
-        <translation type="unfinished"></translation>
+        <translation>Checking printer settings...</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="317"/>
         <source>Success</source>
-        <translation type="unfinished"></translation>
+        <translation>Success</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="327"/>
         <source>Failed to get printer attributes, error: </source>
-        <translation type="unfinished"></translation>
+        <translation>Failed to get printer attributes, error: </translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="335"/>
         <source>%1 is disabled</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 is disabled</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="344"/>
         <source>is not accepting jobs</source>
-        <translation type="unfinished"></translation>
+        <translation>is not accepting jobs</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="349"/>
         <source>Printer settings are ok</source>
-        <translation type="unfinished"></translation>
+        <translation>Printer settings are ok</translation>
     </message>
 </context>
 <context>
@@ -72,42 +72,42 @@
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="211"/>
         <source>Check printer connection</source>
-        <translation type="unfinished"></translation>
+        <translation>Check printer connection</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="223"/>
         <source>Checking printer connection...</source>
-        <translation type="unfinished"></translation>
+        <translation>Checking printer connection...</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="226"/>
         <source>Success</source>
-        <translation type="unfinished"></translation>
+        <translation>Success</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="263"/>
         <source>Cannot connect to the printer, error: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Cannot connect to the printer, error: %1</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="271"/>
         <source> is not connected, URI: </source>
-        <translation type="unfinished"></translation>
+        <translation> is not connected, URI: </translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="280"/>
         <source>%1 does not exist</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 does not exist</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="288"/>
         <source>Cannot connect to the printer</source>
-        <translation type="unfinished"></translation>
+        <translation>Cannot connect to the printer</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="294"/>
         <source>The connection is valid</source>
-        <translation type="unfinished"></translation>
+        <translation>The connection is valid</translation>
     </message>
 </context>
 <context>
@@ -115,22 +115,22 @@
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="109"/>
         <source>Check CUPS server</source>
-        <translation type="unfinished"></translation>
+        <translation>Check CUPS server</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="115"/>
         <source>Checking CUPS server...</source>
-        <translation type="unfinished"></translation>
+        <translation>Checking CUPS server...</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="117"/>
         <source>CUPS server is invalid</source>
-        <translation type="unfinished"></translation>
+        <translation>CUPS server is invalid</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="122"/>
         <source>CUPS server is valid</source>
-        <translation type="unfinished"></translation>
+        <translation>CUPS server is valid</translation>
     </message>
 </context>
 <context>
@@ -138,134 +138,134 @@
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="140"/>
         <source>Checking driver...</source>
-        <translation type="unfinished"></translation>
+        <translation>Checking driver...</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="143"/>
         <source>Success</source>
-        <translation type="unfinished"></translation>
+        <translation>Success</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="151"/>
         <source>PPD file %1 not found</source>
-        <translation type="unfinished"></translation>
+        <translation>PPD file %1 not found</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="161"/>
         <source>The driver is damaged</source>
-        <translation type="unfinished"></translation>
+        <translation>The driver is damaged</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="177"/>
         <source>Driver filter %1 not found</source>
-        <translation type="unfinished"></translation>
+        <translation>Driver filter %1 not found</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="189"/>
         <source>%1 is not installed, cannot print now</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 is not installed, cannot print now</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="195"/>
         <source>Driver is valid</source>
-        <translation type="unfinished"></translation>
+        <translation>Driver is valid</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="201"/>
         <source>Check driver</source>
-        <translation type="unfinished"></translation>
+        <translation>Check driver</translation>
     </message>
 </context>
 <context>
     <name>CupsMonitor</name>
     <message>
-        <location filename="../dbus/zcupsmonitor.cpp" line="77"/>
+        <location filename="../dbus/zcupsmonitor.cpp" line="99"/>
         <source>Queuing</source>
-        <translation type="unfinished"></translation>
+        <translation>Queuing</translation>
     </message>
     <message>
-        <location filename="../dbus/zcupsmonitor.cpp" line="78"/>
+        <location filename="../dbus/zcupsmonitor.cpp" line="100"/>
         <source>Paused</source>
-        <translation type="unfinished"></translation>
+        <translation>Paused</translation>
     </message>
     <message>
-        <location filename="../dbus/zcupsmonitor.cpp" line="79"/>
+        <location filename="../dbus/zcupsmonitor.cpp" line="101"/>
         <source>Printing</source>
-        <translation type="unfinished"></translation>
+        <translation>Printing</translation>
     </message>
     <message>
-        <location filename="../dbus/zcupsmonitor.cpp" line="80"/>
+        <location filename="../dbus/zcupsmonitor.cpp" line="102"/>
         <source>Stopped</source>
-        <translation type="unfinished"></translation>
+        <translation>Stopped</translation>
     </message>
     <message>
-        <location filename="../dbus/zcupsmonitor.cpp" line="81"/>
+        <location filename="../dbus/zcupsmonitor.cpp" line="103"/>
         <source>Canceled</source>
-        <translation type="unfinished"></translation>
+        <translation>Canceled</translation>
     </message>
     <message>
-        <location filename="../dbus/zcupsmonitor.cpp" line="82"/>
+        <location filename="../dbus/zcupsmonitor.cpp" line="104"/>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Error</translation>
     </message>
     <message>
-        <location filename="../dbus/zcupsmonitor.cpp" line="83"/>
+        <location filename="../dbus/zcupsmonitor.cpp" line="105"/>
         <source>Completed</source>
-        <translation type="unfinished"></translation>
+        <translation>Completed</translation>
     </message>
     <message>
-        <location filename="../dbus/zcupsmonitor.cpp" line="338"/>
+        <location filename="../dbus/zcupsmonitor.cpp" line="369"/>
         <source>%1 timed out, reason: %2</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 timed out, reason: %2</translation>
     </message>
     <message>
-        <location filename="../dbus/zcupsmonitor.cpp" line="352"/>
+        <location filename="../dbus/zcupsmonitor.cpp" line="383"/>
         <source>%1 has been sent to the printer, please take away the paper in time!</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 has been sent to the printer, please take away the paper in time!</translation>
     </message>
     <message>
-        <location filename="../dbus/zcupsmonitor.cpp" line="354"/>
+        <location filename="../dbus/zcupsmonitor.cpp" line="385"/>
         <source>%1 %2, reason: %3</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 %2, reason: %3</translation>
     </message>
 </context>
 <context>
     <name>DriverManager</name>
     <message>
-        <location filename="../../Common/vendor/zdrivermanager.cpp" line="1022"/>
+        <location filename="../../Common/vendor/zdrivermanager.cpp" line="1031"/>
         <source>EveryWhere driver</source>
-        <translation type="unfinished"></translation>
+        <translation>EveryWhere driver</translation>
     </message>
 </context>
 <context>
     <name>InstallDriver</name>
     <message>
-        <location filename="../../Common/vendor/addprinter.cpp" line="372"/>
+        <location filename="../../Common/vendor/addprinter.cpp" line="373"/>
         <source>Failed to find the driver solution: %1, error: %2</source>
-        <translation type="unfinished"></translation>
+        <translation>Failed to find the driver solution: %1, error: %2</translation>
     </message>
     <message>
-        <location filename="../../Common/vendor/addprinter.cpp" line="383"/>
+        <location filename="../../Common/vendor/addprinter.cpp" line="384"/>
         <source>The solution is invalid</source>
-        <translation type="unfinished"></translation>
+        <translation>The solution is invalid</translation>
     </message>
 </context>
 <context>
     <name>InstallInterface</name>
     <message>
-        <location filename="../../Common/vendor/addprinter.cpp" line="250"/>
+        <location filename="../../Common/vendor/addprinter.cpp" line="251"/>
         <source>is invalid</source>
-        <translation type="unfinished"></translation>
+        <translation>is invalid</translation>
     </message>
     <message>
-        <location filename="../../Common/vendor/addprinter.cpp" line="279"/>
+        <location filename="../../Common/vendor/addprinter.cpp" line="280"/>
         <source>Failed to install the driver by calling dbus interface</source>
-        <translation type="unfinished"></translation>
+        <translation>Failed to install the driver by calling dbus interface</translation>
     </message>
     <message>
-        <location filename="../../Common/vendor/addprinter.cpp" line="324"/>
+        <location filename="../../Common/vendor/addprinter.cpp" line="325"/>
         <source>Failed to install %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Failed to install %1</translation>
     </message>
 </context>
 <context>
@@ -273,7 +273,7 @@
     <message>
         <location filename="../../Common/zjobmanager.cpp" line="307"/>
         <source> not found</source>
-        <translation type="unfinished"></translation>
+        <translation> not found</translation>
     </message>
 </context>
 <context>
@@ -281,48 +281,48 @@
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="370"/>
         <source>Check test page printing</source>
-        <translation type="unfinished"></translation>
+        <translation>Check test page printing</translation>
     </message>
     <message>
         <location filename="../../Common/vendor/ztroubleshoot.cpp" line="424"/>
         <source>Printing test page...</source>
-        <translation type="unfinished"></translation>
+        <translation>Printing test page...</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <location filename="../../Common/common.cpp" line="154"/>
-        <source> not found, please ask the administrator for help</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../main.cpp" line="65"/>
         <source>Print Manager</source>
-        <translation type="unfinished"></translation>
+        <translation>Print Manager</translation>
     </message>
     <message>
         <location filename="../main.cpp" line="66"/>
         <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
-        <translation type="unfinished"></translation>
+        <translation>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</translation>
+    </message>
+    <message>
+        <location filename="../../Common/common.cpp" line="154"/>
+        <source>%1 not found, please ask the administrator for help, or enter the printer IP address in URI of Properties.</source>
+        <translation>%1 not found, please ask the administrator for help, or enter the printer IP address in URI of Properties.</translation>
     </message>
 </context>
 <context>
     <name>USBThread</name>
     <message>
-        <location filename="../usbprinter/usbthread.cpp" line="256"/>
+        <location filename="../usbprinter/usbthread.cpp" line="260"/>
         <source>Configuring the printer %1 ...</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../usbprinter/usbthread.cpp" line="302"/>
-        <source>Configuration successful. Click to view %1.</source>
-        <translation type="unfinished"></translation>
+        <translation>Configuring the printer %1 ...</translation>
     </message>
     <message>
         <location filename="../usbprinter/usbthread.cpp" line="306"/>
+        <source>Configuration successful. Click to view %1.</source>
+        <translation>Configuration successful. Click to view %1.</translation>
+    </message>
+    <message>
+        <location filename="../usbprinter/usbthread.cpp" line="310"/>
         <source>Configuration failed. Click to add the printer %1.</source>
-        <translation type="unfinished"></translation>
+        <translation>Configuration failed. Click to add the printer %1.</translation>
     </message>
 </context>
 </TS>
