@@ -125,7 +125,7 @@ static QString formatDataTimeString(const QDateTime &dataTime)
         }
     }
 
-    return dataTime.toString("yyyy:MM:dd HH::mm::ss");
+    return dataTime.toString("yyyy-MM-dd HH:mm:ss");
 }
 
 static QPixmap getActionPixmap(unsigned int iAction, QIcon::Mode mode = QIcon::Normal);
@@ -408,8 +408,8 @@ bool JobListView::askDeleteJobs(unsigned int flag)
         return true;
 
     dlg.setIcon(QIcon(":/images/warning_logo.svg"));
-    dlg.addButton(tr("Cancel"), true);
-    iAccept = dlg.addButton(tr("Delete"), false, DDialog::ButtonWarning);
+    dlg.addButton(tr("Cancel", "button"), true);
+    iAccept = dlg.addButton(tr("Delete", "button"), false, DDialog::ButtonWarning);
     dlg.getButton(0)->setFixedSize(170, 36);
     dlg.getButton(1)->setFixedSize(170, 36);
     dlg.setModal(true);
@@ -893,7 +893,7 @@ void JobsDataModel::slotRefreshJobsList()
 
     qInfo() << m_iWhichJob;
 
-    if (0 != g_jobManager->getJobs(jobsmap, m_iWhichJob))
+    if (0 != g_jobManager->getJobs(jobsmap, m_iWhichJob, 1))
         return;
 
     m_jobs.clear();
@@ -1094,6 +1094,7 @@ void JobManagerWindow::createUi()
 
 void JobManagerWindow::initUi()
 {
+    setWindowFlags(windowFlags() & ~Qt::WindowMaximizeButtonHint);
     m_refreshBut->setIcon(QIcon::fromTheme("dp_refresh"));
     m_refreshBut->setToolTip(tr("Refresh"));
     m_refreshBut->setAccessibleName("refreshBut_jobsWindow");
@@ -1117,9 +1118,11 @@ void JobManagerWindow::initUi()
     m_jobsView->setModel(m_jobsModel);
     m_jobsView->setAccessibleName("jobsView_jobsWindow");
     m_jobsView->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
-    m_jobsView->horizontalHeader()->setSectionResizeMode(0, QHeaderView::Fixed);
-    m_jobsView->horizontalHeader()->setSectionResizeMode(1, QHeaderView::Fixed);
-    m_jobsView->horizontalHeader()->setSectionResizeMode(4, QHeaderView::Fixed);
+    m_jobsView->horizontalHeader()->setSectionResizeMode(0, QHeaderView::Interactive);
+    m_jobsView->horizontalHeader()->setSectionResizeMode(1, QHeaderView::Interactive);
+    m_jobsView->horizontalHeader()->setSectionResizeMode(2, QHeaderView::Interactive);
+    m_jobsView->horizontalHeader()->setSectionResizeMode(3, QHeaderView::Interactive);
+    m_jobsView->horizontalHeader()->setSectionResizeMode(4, QHeaderView::Interactive);
     m_jobsView->horizontalHeader()->setSectionResizeMode(5, QHeaderView::Interactive);
     m_jobsView->horizontalHeader()->setSectionResizeMode(6, QHeaderView::Interactive);
     m_jobsView->setColumnWidth(0, 72);
@@ -1138,7 +1141,7 @@ void JobManagerWindow::initUi()
     pa.setColor(QPalette::WindowText, color);
     m_jobCountLabel->setPalette(pa);
 
-    setMinimumSize(JOB_VIEW_WIDTH, 546);
+    setFixedSize(JOB_VIEW_WIDTH, 546);
     takeCentralWidget();
 
     QWidget *centWidget = new QWidget(this);
